==> paper-api-1.16.3-R0.1-20200914.100250-6-sources.jar: com/destroystokyo/paper/event/entity/EntityPathfindEvent.java <==
package com.destroystokyo.paper.event.entity;

import org.bukkit.Location;
import org.bukkit.entity.Entity;
import org.bukkit.event.Cancellable;
import org.bukkit.event.HandlerList;
import org.bukkit.event.entity.EntityEvent;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

/**
 * Fired when an Entity decides to start moving towards a location.
 *
 * This event does not fire for the entities actual movement. Only when it
 * is choosing to start moving to a location.
 */
public class EntityPathfindEvent extends EntityEvent implements Cancellable {
    @Nullable private final Entity targetEntity;
    @NotNull private final Location loc;

    public EntityPathfindEvent(@NotNull Entity entity, @NotNull Location loc, @Nullable Entity targetEntity) {
        super(entity);
        this.targetEntity = targetEntity;
        this.loc = loc;
    }

    /**
     * The Entity that is pathfinding.
     * @return The Entity that is pathfinding.
     */
    @NotNull
    public Entity getEntity() {
        return entity;
    }

    /**
     * If the Entity is trying to pathfind to an entity, this is the entity in relation.
     *
     * Otherwise this will return null.
     *
     * @return The entity target or null
     */
    @Nullable
    public Entity getTargetEntity() {
        return targetEntity;
    }

    /**
     * The Location of where the entity is about to move to.
     *
     * Note that if the target happened to of been an entity
     * @return Location of where the entity is trying to pathfind to.
     */
    @NotNull
    public Location getLoc() {
        return loc;
    }

    private static final HandlerList handlers = new HandlerList();

    @NotNull
    public HandlerList getHandlers() {
        return handlers;
    }

    @NotNull
    public static HandlerList getHandlerList() {
        return handlers;
    }

    private boolean cancelled = false;

    @Override
    public boolean isCancelled() {
        return cancelled;
    }

    @Override
    public void setCancelled(boolean cancel) {
        cancelled = cancel;
    }
}

==> paper-api-1.20.6-R0.1-20241030.191541-127-sources.jar: com/destroystokyo/paper/event/entity/EntityPathfindEvent.java <==
package com.destroystokyo.paper.event.entity;

import org.bukkit.Location;
import org.bukkit.entity.Entity;
import org.bukkit.event.Cancellable;
import org.bukkit.event.HandlerList;
import org.bukkit.event.entity.EntityEvent;
import org.jetbrains.annotations.ApiStatus;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

/**
 * Fired when an Entity decides to start moving towards a location.
 * <p>
 * This event does not fire for the entities actual movement. Only when it
 * is choosing to start moving to a location.
 */
public class EntityPathfindEvent extends EntityEvent implements Cancellable {

    private static final HandlerList HANDLER_LIST = new HandlerList();

    @Nullable private final Entity targetEntity;
    @NotNull private final Location location;
    private boolean cancelled;

    @ApiStatus.Internal
    public EntityPathfindEvent(@NotNull Entity entity, @NotNull Location location, @Nullable Entity targetEntity) {
        super(entity);
        this.targetEntity = targetEntity;
        this.location = location;
    }

    /**
     * The Entity that is pathfinding.
     *
     * @return The Entity that is pathfinding.
     */
    @NotNull
    public Entity getEntity() {
        return this.entity;
    }

    /**
     * If the Entity is trying to pathfind to an entity, this is the entity in relation.
     * <br>
     * Otherwise this will return {@code null}.
     *
     * @return The entity target or {@code null}
     */
    @Nullable
    public Entity getTargetEntity() {
        return this.targetEntity;
    }

    /**
     * The Location of where the entity is about to move to.
     * <br>
     * Note that if the target happened to of been an entity
     *
     * @return Location of where the entity is trying to pathfind to.
     */
    @NotNull
    public Location getLoc() {
        return this.location.clone();
    }

    @Override
    public boolean isCancelled() {
        return this.cancelled;
    }

    @Override
    public void setCancelled(boolean cancel) {
        this.cancelled = cancel;
    }

    @NotNull
    @Override
    public HandlerList getHandlers() {
        return HANDLER_LIST;
    }

    @NotNull
    public static HandlerList getHandlerList() {
        return HANDLER_LIST;
    }
}
